@@ -569,18 +569,18 @@ void irreco_window_edit_main_menu_create(IrrecoWindowEdit * edit_window)
 			       GTK_BUTTON(edit_window->menu_save));
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_controllers));
-	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
-			       GTK_BUTTON(edit_window->menu_hardkeys));
-	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
-			       GTK_BUTTON(edit_window->menu_devices));
+	/*hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
+			       GTK_BUTTON(edit_window->menu_hardkeys));*/
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_background));
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
-			       GTK_BUTTON(edit_window->menu_download_lirc));
+			       GTK_BUTTON(edit_window->menu_devices));
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_theme_manager));
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
-			       GTK_BUTTON(edit_window->menu_download_irtrans));
+			       GTK_BUTTON(edit_window->menu_download_lirc));
+	/*hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
+			       GTK_BUTTON(edit_window->menu_download_irtrans));*/
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_newbutton));
 
